Jupyter ThreeJS Widget
======================

Interactive Threejs widget for the Jupyter notebook

The reference Python backend, `pythreejs` is available
[here](https://github.com/jovyan/pythreejs), with examples.

Package Install
---------------

**Prerequisites**
- [node](http://nodejs.org/)

```bash
npm install --save jupyter-threejs
```
